@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import List, Sequence, cast
 
 import thot.alignment as ta
@@ -56,6 +58,9 @@ class ThotSymmetrizedWordAlignmentModel(SymmetrizedWordAlignmentModel):
 
         return _Trainer(self, direct_trainer, inverse_trainer)
 
+    def __enter__(self) -> ThotSymmetrizedWordAlignmentModel:
+        return self
+
     def _reset_aligner(self) -> None:
         self._aligner = ta.SymmetrizedAligner(
             self.direct_word_alignment_model.thot_model, self.inverse_word_alignment_model.thot_model
